summaryrefslogtreecommitdiff
path: root/gtk
diff options
context:
space:
mode:
authorOwen Taylor <otaylor@redhat.com>2001-01-09 16:23:57 +0000
committerOwen Taylor <otaylor@src.gnome.org>2001-01-09 16:23:57 +0000
commita801ea7bf04ab77c30b2ab9dbb487095575f1a3e (patch)
tree01de5ce6090e09a60d412d8d90562a36e6c6db4f /gtk
parent7e3eadd61ca2304b2f9fa0430c2f1271c41b49ab (diff)
downloadgdk-pixbuf-a801ea7bf04ab77c30b2ab9dbb487095575f1a3e.tar.gz
Doc fixups.
Tue Jan 9 11:20:48 2001 Owen Taylor <otaylor@redhat.com> * gtk/gtktreeview.[ch] gtktreemodelsort.[ch] gtknotebook.c gdk/gdk-pixbuf.h: Doc fixups. * gtk/gtkobject.h: Remove trailing , from enum
Diffstat (limited to 'gtk')
-rw-r--r--gtk/gtknotebook.c28
-rw-r--r--gtk/gtkobject.h2
-rw-r--r--gtk/gtktreemodelsort.c8
-rw-r--r--gtk/gtktreemodelsort.h2
-rw-r--r--gtk/gtktreeview.c2
-rw-r--r--gtk/gtktreeview.h2
6 files changed, 20 insertions, 24 deletions
diff --git a/gtk/gtkobject.h b/gtk/gtkobject.h
index 239c21d07..a53f1d3d7 100644
--- a/gtk/gtkobject.h
+++ b/gtk/gtkobject.h
@@ -216,7 +216,7 @@ typedef enum
GTK_ARG_WRITABLE = G_PARAM_WRITABLE,
GTK_ARG_CONSTRUCT = G_PARAM_CONSTRUCT,
GTK_ARG_CONSTRUCT_ONLY = G_PARAM_CONSTRUCT_ONLY,
- GTK_ARG_CHILD_ARG = 1 << 4,
+ GTK_ARG_CHILD_ARG = 1 << 4
} GtkArgFlags;
#define GTK_ARG_READWRITE (GTK_ARG_READABLE | GTK_ARG_WRITABLE)
void gtk_object_get (GtkObject *object,
diff --git a/gtk/gtktreemodelsort.c b/gtk/gtktreemodelsort.c
index 5b30458f4..138d5bbc4 100644
--- a/gtk/gtktreemodelsort.c
+++ b/gtk/gtktreemodelsort.c
@@ -324,13 +324,13 @@ gtk_tree_model_sort_set_model (GtkTreeModelSort *tree_model_sort,
/**
* gtk_tree_model_sort_convert_path:
* @tree_model_sort: The #GtkTreeModelSort.
- * @path: A #GtkTreePath, relative to the child model.
+ * @child_path: A #GtkTreePath, relative to the child model.
*
- * Converts the @path to a new path, relative to the sorted position. In other
- * words, the value found in the @tree_model_sort ->child_model at the @path, is
+ * Converts the @child_path to a new path, relative to the sorted position. In other
+ * words, the value found in the @tree_model_sort ->child_model at the @child_path, is
* identical to that found in the @tree_model_sort and the return value.
*
- * Return value: A new path, or NULL if @path does not exist in @tree_model_sort
+ * Return value: A new path, or NULL if @child_path does not exist in @tree_model_sort
* ->child_model.
**/
GtkTreePath *
diff --git a/gtk/gtktreemodelsort.h b/gtk/gtktreemodelsort.h
index 66a345377..ac76d626e 100644
--- a/gtk/gtktreemodelsort.h
+++ b/gtk/gtktreemodelsort.h
@@ -77,7 +77,7 @@ GtkTreeModel *gtk_tree_model_sort_new_with_model (GtkTreeModel *child_model
GValueCompareFunc func,
gint sort_col);
void gtk_tree_model_sort_set_model (GtkTreeModelSort *tree_model_sort,
- GtkTreeModel *model);
+ GtkTreeModel *child_model);
GtkTreePath *gtk_tree_model_sort_convert_path (GtkTreeModelSort *tree_model_sort,
GtkTreePath *child_path);
diff --git a/gtk/gtktreeview.c b/gtk/gtktreeview.c
index ccf056ff2..d7c121fa0 100644
--- a/gtk/gtktreeview.c
+++ b/gtk/gtktreeview.c
@@ -3288,7 +3288,7 @@ gtk_tree_view_columns_autosize (GtkTreeView *tree_view)
**/
void
gtk_tree_view_set_headers_clickable (GtkTreeView *tree_view,
- gboolean setting)
+ gboolean setting)
{
GList *list;
diff --git a/gtk/gtktreeview.h b/gtk/gtktreeview.h
index c2870d45c..58709893f 100644
--- a/gtk/gtktreeview.h
+++ b/gtk/gtktreeview.h
@@ -78,7 +78,7 @@ void gtk_tree_view_set_headers_visible (GtkTreeView *tr
gboolean headers_visible);
void gtk_tree_view_columns_autosize (GtkTreeView *tree_view);
void gtk_tree_view_set_headers_clickable (GtkTreeView *tree_view,
- gboolean active);
+ gboolean setting);
gint gtk_tree_view_append_column (GtkTreeView *tree_view,
GtkTreeViewColumn *column);
gint gtk_tree_view_remove_column (GtkTreeView *tree_view,
diff --git a/gtk/gtknotebook.c b/gtk/gtknotebook.c
index fecef3b6b..4c0994af4 100644
--- a/gtk/gtknotebook.c
+++ b/gtk/gtknotebook.c
@@ -372,7 +372,6 @@ gtk_notebook_init (GtkNotebook *notebook)
/**
* gtk_notebook_new:
- * @void:
*
* Creates a new #GtkNotebook widget with no pages.
@@ -4099,22 +4098,21 @@ gtk_notebook_set_homogeneous_tabs (GtkNotebook *notebook,
/**
* gtk_notebook_set_tab_border:
* @notebook: a #GtkNotebook
* @tab_border: %TRUE if there should be a border around the
* tab labels.
*
* Sets whether there should be a border around the tab labels
* in a notebook. This is equivalent to calling
- * gtk_notebook_set_tab_hborder (@notebook, @tab_border) followed
- * by gtk_noteobok_set_tab_vborder (@notebook, @tab_border).
+ * gtk_notebook_set_tab_hborder (@notebook, @border_width) followed
+ * by gtk_noteobok_set_tab_vborder (@notebook, @border_width).
**/
void
gtk_notebook_set_tab_border (GtkNotebook *notebook,
- guint tab_border)
+ guint border_width)
{
g_return_if_fail (GTK_IS_NOTEBOOK (notebook));
- notebook->tab_hborder = tab_border;
- notebook->tab_vborder = tab_border;
+ notebook->tab_hborder = border_width;
+ notebook->tab_vborder = border_width;
if (GTK_WIDGET_VISIBLE (notebook) && notebook->show_tabs)
gtk_widget_queue_resize (GTK_WIDGET (notebook));
@@ -4123,10 +4121,9 @@ gtk_notebook_set_tab_border (GtkNotebook *notebook,
/**
* gtk_notebook_set_tab_hborder:
* @notebook: a #GtkNotebook
- * @tab_vborder: %TRUE if the notebook tabs should have
- * a vertical border.
+ * @tab_hborder: width of the horizontal border of tab labels.
*
- * Sets whether the tabs should have a vertical border.
+ * Sets the width of the horizontal border of tab labels.
**/
void
gtk_notebook_set_tab_hborder (GtkNotebook *notebook,
@@ -4146,10 +4143,9 @@ gtk_notebook_set_tab_hborder (GtkNotebook *notebook,
/**
* gtk_notebook_set_tab_vborder:
* @notebook: a #GtkNotebook
* @tab_vborder: %TRUE if the notebook tabs should have
* a vertical border.
*
* Sets whether the tabs should have a vertical border.
**/
void
gtk_notebook_set_tab_vborder (GtkNotebook *notebook,
@@ -4368,7 +4364,7 @@ gtk_notebook_set_tab_label (GtkNotebook *notebook,
* gtk_notebook_set_tab_label_text:
* @notebook: a #GtkNotebook
* @child: the page
- * @tab_label: the label text
+ * @tab_text: the label text
*
* Creates a new label and sets it as the tab label for the page
* containing @child.
@@ -4099,22 +4098,21 @@ gtk_notebook_set_homogeneous_tabs (GtkNotebook *notebook,
* gtk_notebook_set_tab_border:
* @notebook: a #GtkNotebook
- * @tab_border: %TRUE if there should be a border around the
- * tab labels.
+ * @border_width: width of the border around the tab labels.
*
@@ -4099,22 +4098,21 @@ gtk_notebook_set_homogeneous_tabs (GtkNotebook *notebook,
*
- * Sets whether there should be a border around the tab labels
+ * Sets the width the border around the tab labels
* in a notebook. This is equivalent to calling
@@ -4146,10 +4143,9 @@ gtk_notebook_set_tab_hborder (GtkNotebook *notebook,
* gtk_notebook_set_tab_vborder:
* @notebook: a #GtkNotebook
- * @tab_vborder: %TRUE if the notebook tabs should have
- * a vertical border.
+ * @tab_vborder: width of the vertical border of tab labels.
*
@@ -4146,10 +4143,9 @@ gtk_notebook_set_tab_hborder (GtkNotebook *notebook,
*
- * Sets whether the tabs should have a vertical border.
+ * Sets the width of the vertical border of tab labels.
**/
void